@@ -1,6 +1,6 @@
 (*
  * This file is part of Bisect.
- * Copyright (C) 2008-2011 Xavier Clerc.
+ * Copyright (C) 2008-2012 Xavier Clerc.
  *
  * Bisect is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,10 @@
 
 val output : (string -> unit) -> string -> int -> string -> bool -> bool -> (string -> string) -> (string, int array) Hashtbl.t -> unit
 (** [output verbose dir tab_size title no_navbar no_folding resolver data]
-    writes all the HTML files for [data] in the directory [dir]. [verbose] is
-    used for verbose output, [tab_size] is the number of space characters to
-    use as a replacement for tabulations, [no_navbar] indicates whether
-    navigation bar should be disabled, [no_folding] indicates whether code
-    folding should be disabled, [title] is the title for generated pages, and
-    [resolver] associates the actual path to a given filename. *)
+    writes all the HTML files for [data] in the directory [dir]. [verbose]
+    is used for verbose output, [tab_size] is the number of space
+    characters to use as a replacement for tabulations, [no_navbar]
+    indicates whether navigation bar should be disabled, [no_folding]
+    indicates whether code folding should be disabled, [title] is the
+    title for generated pages, and [resolver] associates the actual path
+    to a given filename. *)
