@@ -1,6 +1,6 @@
 (*
  * This file is part of Bisect.
- * Copyright (C) 2008-2011 Xavier Clerc.
+ * Copyright (C) 2008-2012 Xavier Clerc.
  *
  * Bisect is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,5 +19,6 @@
 (** This module defines the output to bare text. *)
 
 
-val make : unit -> ReportGeneric.converter
-(** Returns a converter for bare text output. *)
+val make : bool -> ReportGeneric.converter
+(** Returns a converter for bare text output, the passed boolean indicates
+    whether only summary should be output. *)
