@@ -1,6 +1,6 @@
 (*
  * This file is part of Bisect.
- * Copyright (C) 2008-2011 Xavier Clerc.
+ * Copyright (C) 2008-2012 Xavier Clerc.
  *
  * Bisect is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,8 @@
 val make : unit -> ReportGeneric.converter
 (** Returns a converter for XML output, using EMMA format.
 
-    EMMA is a Java code coverage available at {i http://emma.sourceforge.net/}.
-    The returned converter only outputs overall statistics, and generated files
-    are intended to be used by reporintg tools like the EMMA plugin for the
-    Hudson continuous integration server (available at {i http://hudson-ci.org/}). *)
+    EMMA is a Java code coverage available at
+    {i http://emma.sourceforge.net/}. The returned converter only outputs
+    overall statistics, and generated files are intended to be used by
+    reporintg tools like the EMMA plugin for the Jenkins continuous
+    integration server (available at {i http://jenkins-ci.org/}). *)
